/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * CVfast_data.h
 *
 * Code generation for function 'CVfast_data'
 *
 */

#ifndef CVFAST_DATA_H
#define CVFAST_DATA_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_defines.h"
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "CVfast_types.h"

/* Variable Declarations */
extern unsigned int state[625];
//extern omp_nest_lock_t emlrtNestLockGlobal;

#endif

/* End of code generation (CVfast_data.h) */
